from twisted.application import service, internet

from axiom.store import Store

from kali.controller import ServicesController
from kali.nickserv import NickServ
from kali.ares import AresServ
from kali.oper import OperServ
from kali.protocol import ServicesFactory, InspircdServices

try:
    from twisted.internet import ssl as twssl
except:
    twssl = None

def deploy(host, port, dbname, dbuser, dbpass, ssl=False, **params):
    application = service.Application('kali')

    store = Store('kali.axiom')

    def ctrlFactory():
        ctrl = ServicesController(store, params)
        ctrl.addService(NickServ(ctrl))
        ctrl.addService(AresServ(ctrl))
        ctrl.addService(OperServ(ctrl))
        return ctrl

    factory = ServicesFactory(ctrlFactory, InspircdServices)

    if ssl:
        services = internet.SSLClient(host, port, factory, twssl.ClientContextFactory())
    else:
        services = internet.TCPClient(host, port, factory)

    services.setServiceParent(application)

    return application
