from zope.interface import Interface, Attribute


class ICommand(Interface):
    name = Attribute("""
    A C{str} that is the command's name.
    """)

    usage = Attribute("""
    A single-line C{str} that details usage/syntax information for the command.
    """)

    help = Attribute("""
    A C{str}, optionally multi-line, that goes into detail about this command's
    behaviour and any related information.
    """)

    def locateCommand(params):
        """
        Find the C{ICommand} handler responsible for a given command.

        The first parameter is popped from C{params} and is treated as the
        command handler name. If no handler is found L{UsageError} is raised.

        @param params: The parameters, including the command, for a command
        @type params: C{list}

        @return: The command handler for the command and the remaining parameters
        @rtype: C{(ICommand, list)}
        """

    def invoke(pseudo):
        """
        @param pseudo: The pseudoclient that invoked the command
        @type pseudo: L{Pseudo} instance
        """
